@@ -1,15 +1,37 @@
 from django.forms import Field, TextInput, Media
 from django.conf import settings
 from django.utils.safestring import mark_safe
+from django.utils.translation import ugettext as _, get_language
+from pyuploadcare.dj.conf import USE_HOSTED_ASSETS
+
+UPLOADCARE_JS = 'http://static.uploadcare.com/assets/uploaders/line-widget.%(lang)s.js'
+UPLOADCARE_LOCAL_JS = 'uploadcare/assets/uploaders/line-widget.%(lang)s.js'
+
+AVAIL_ASSET_LANG = ('en', 'ru', 'pl')
+
+def get_asset_lang():
+    '''returns a localized asset url '''
+    lang = get_language()
+    if lang.startswith('en'):
+        lang = lang[:2]
+
+    if not lang in AVAIL_ASSET_LANG:
+        lang = 'en'
+
+    BASE_ASSET_URL = UPLOADCARE_JS
+    if not USE_HOSTED_ASSETS:
+        BASE_ASSET_URL = UPLOADCARE_LOCAL_JS
+
+    return BASE_ASSET_URL % {'lang' : lang}
 
-UPLOADCARE_JS = 'http://static.uploadcare.com/assets/uploaders/line-widget.en.js'
 
 class FileWidget(TextInput):
     input_type = 'hidden'
 
     class Media:
-        js = (UPLOADCARE_JS,)
+        js = (get_asset_lang(),)
     
+
     def __init__(self, attrs=None):
         from pyuploadcare.dj import UploadCare
 
@@ -29,9 +51,9 @@ class FileWidget(TextInput):
             if value.url():
                 fname = '<a href="%s">%s</a>' % (value.url(), value.filename())
             else:
-                fname = '%s (unavail.)' % value.filename()
+                fname = '%s (%s)' % (value.filename(), _('unavail.'))
 
-            description = '<p>File: %s</p>' % fname
+            description = '<p>%s: %s</p>' % (_('File'), fname)
 
             html = mark_safe(html + description)
 
